% Test for the odeEuler routine

% Solve the differential equation 
%
%           y' = f(t,y)
%        y(t0) = y0
%
% with
% f(t,y) = -y
%     t0 = 0
%     y0 = 1
%
% The exact analitical solution is y(t)= exp(-t)
% while the exact numerical solution is y_n(t) = (1-h)^n * y0

close all
clear all
clc


odefun = inline('-y','t','y');
tspan = [0,1];
y0 = 1;
h = 0.1;
[t,y] = odeEuler(odefun,tspan,y0,h);

% evaluation of the analitical solution
yexact = exp(-t);

% evaluation of the numerical solution
ynexact = ((1-h)*ones(size(t))).^((0:length(t)-1)');
ynexact = ynexact.*y0;

% print solutions
fprintf('t     y         ynexact   yexact    errn      err\n');
fprintf('%2.2f  %2.6f  %2.6f  %2.6f  %2.6f  %2.6f\n',[t,y,ynexact,yexact,abs(ynexact-y),abs(yexact-y)]');
