function [t,y] = odeHeun(odefun,tspan,y0,h)
%odeEuler Solve ordinary differential equations using the Heun method.
%
% SYNOPSIS
%    [t,y] = odeHeun(odefun,tspan,y0,h)
%
% INPUT
%   odefun : The f(t,y) function of the y'= f(t,y) differential equations
%   tspan  : Initial (tspan(1)) and stopping value (tspan(2)) of the integration procedure
%   y0     : Initial condition for the dependent variable
%   h      : stepsize
%
% OUTPUT
%   t : vector of independent variable value
%   y : vector of dependent variable value


t = (tspan(1):h:tspan(2))'; % preallocate independent elements
n = length(t);              % total number of elements
y = zeros(n,1);             % preallocate dependent elements
y(1) = y0;                  % set initial value

% Main loop
for j=1:n-1
   k1 = feval(odefun,t(j),y(j));
   k2 = feval(odefun,t(j)+h,y(j)+h*k1);
   y(j+1) = y(j)+h*(k1+k2)/2;
end
