% Test for the odeHeun routine

% Solve the differential equation 
%
%           y' = f(t,y)
%        y(t0) = y0
%
% with
% f(t,y) = -y
%     t0 = 0
%     y0 = 1
%
% The exact analitical solution is y(t)= exp(-t).

close all
clear all
clc


odefun = inline('-y','t','y');
tspan = [0,1];
y0 = 1;
h = 0.1;
[t,y] = odeHeun(odefun,tspan,y0,h);

% evaluation of the analitical solution
yexact = exp(-t);


% print solutions
fprintf('t     y         yexact    err\n');
fprintf('%2.2f  %2.6f  %2.6f  %2.6f\n',[t,y,yexact,abs(yexact-y)]');
