% Test for the odeHeun routine

% Solve the differential equation 
%
%           y' = f(t,y)
%        y(t0) = y0
%
% with
% f(t,y) = -y
%     t0 = 0
%     y0 = 1
%
% Compare the error at each iteration
% and show the quadratic behaviour of the method.

close all
clear all
clc


odefun = inline('-y','t','y');
tspan = [0,1];
y0 = 1;

err = zeros(10,1);                      % preallocate error
errh = zeros(10,1);                     % preallocate vector for h values
h = 0.1;                                % initial stepsize
for i=1:10
   disp(['#iter:',num2str(i)]);
   [t,y] = odeHeun(odefun,tspan,y0,h);  % approximate ode
   yexact = exp(-t);                    % evaluate exact solution
   err(i) = max(abs(y-yexact));         % compute maximum error
   errh(i) = h;                         % save h value
   h = h/2;                             % new h value
end

% plot error
figure;
plot(errh,err);

% log scale: e = c*h^p => log e = log c + p * log h (linear relation)
figure;
loglog(errh,err);
plotscale(2);
