% Test for the RK4 routine

% Solve the differential equation 
%
%           y' = f(t,y)
%        y(t0) = y0
%
% with
% f(t,y) = -y
%     t0 = 0
%     y0 = 1
%
% Compare the error at each iteration
% and show the behaviour (p=4) of the method.

close all
clear all
clc


odefun = inline('-y','t','y');
tspan = [0,1];
y0 = 1;

n = 20;                                    % number of subdivisions
err = zeros(10,1);                         % preallocate error
errh = linspace(0.01,1,n);                 % preallocate vector for h values

for i=1:n
   disp(['#iter:',num2str(i)]);
   [t,y] = odeRK4(odefun,tspan,y0,errh(i)); % approximate ode
   yexact = exp(-t);                        % evaluate exact solution
   err(i) = max(abs(y-yexact));             % compute maximum error
end

% plot error
figure;
plot(errh,err);

% log scale: e = c*h^p => log e = log c + p * log h (linear relation)
figure;
loglog(errh,err);
plotscale(4);
