% Solve the pendulum equation with the RK4 method
%
%        theta'' + w*sin(theta) = 0
%                     theta(t0) = theta0
%                    theta(t0)' = dtheta0
%
% with
%      t0 = 0
%  theta0 = pi/4
% dtheta0 = 0
%       w = 9.81/0.61 (g/l)

close all
clear all
clc


odefun = 'pendulumDyDt';
tspan = [0,20];                            % final time step of 20 [s]
y0 = [pi/2,0];                             % [theta0,dtheta0]

h = 0.3;                                   % time-step [s]
[t1,y1] = odeRK4sys(odefun,tspan,y0,h);    % approximation of the ode

% position
figure;
plot(t1,y1(:,1));

% angle
figure;
plot(t1,y1(:,2));

% Poincare' map
figure;
plot(y1(:,1),y1(:,2));


h = 0.1;                                   % time-step [s]
[t2,y2] = odeRK4sys(odefun,tspan,y0,h);    % approximation of the ode

% position
figure;
plot(t2,y2(:,1));

% angle
figure;
plot(t2,y2(:,2));

% Poincare' map
figure;
plot(y2(:,1),y2(:,2));
