% Solve the pendulum equation with the ode45 method
%
%        theta'' + w*sin(theta) = 0
%                     theta(t0) = theta0
%                    theta(t0)' = dtheta0
%
% with
%      t0 = 0
%  theta0 = pi/4
% dtheta0 = 0
%       w = 9.81/0.61 (g/l)

close all
clear all
clc


odefun = 'pendulumDyDt';
tn = 20;                                   % final time step of 20 [s]
y0 = [pi/2,0];                             % [theta0,dtheta0]


options = odeset('Vectorized','on','InitialStep',0.01);
[t,y] = ode45('pendulumDyDt',tn,y0,options);

% position
figure;
plot(t,y(:,1));

% angle
figure;
plot(t,y(:,2));

% Poincare' map
figure;
plot(y(:,1),y(:,2));
